@@ -87,11 +87,7 @@ class Provider(BaseProvider):
             sign = '+' if positive else self.random_element(('+', '-'))
             left_number = self.random_number(left_digits)
 
-        return float("{}{}.{}".format(
-            sign,
-            left_number,
-            self.random_number(right_digits),
-        ))
+        return float(f'{sign}{left_number}.{self.random_number(right_digits)}')
 
     def _safe_random_int(self, min_value, max_value, positive):
         orig_min_value = min_value
@@ -156,7 +152,7 @@ class Provider(BaseProvider):
     def _random_type(self, type_list):
         value_type = self.random_element(type_list)
 
-        method_name = "py{}".format(value_type)
+        method_name = f'py{value_type}'
         if hasattr(self, method_name):
             value_type = method_name
 
